#
# spec file for package kf5-filesystem
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kf5-filesystem
URL:            https://www.kde.org
Version:        20220307
Release:        2.2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Summary:        KF5 Directory Layout
License:        LGPL-2.1-or-later
Group:          System/Fhs
Source0:        macros.kf5
Source1:        COPYING
# https://github.com/openSUSE/rpm-config-SUSE/blob/54f9f71bacdfb944d88f722d71a4d35651f7cc8a/fileattrs/locale.attr
# edited for /usr/share/locale/kf5/
Source2:        localekf5.attr
Source3:        https://raw.githubusercontent.com/openSUSE/rpm-config-SUSE/54f9f71bacdfb944d88f722d71a4d35651f7cc8a/scripts/locale.prov#/localekf5.prov
Requires:       hicolor-icon-theme

%description
This package provides macros which are utilized with extra-cmake-modules' KDEInstallDirs.

%define _kf5_prefix     %{_prefix}
%define _kf5_bindir     %{_kf5_prefix}/bin
%define _kf5_sharedir   %{_datadir}
%define _kf5_datadir    %{_kf5_sharedir}/kf5
%define _kf5_includedir %{_includedir}/KF5
%define _kf5_libdir     %{_kf5_prefix}/%{_lib}
%define _kf5_libexecdir %{_libexecdir}/kf5
%define _kf5_mandir     %{_mandir}
%define _kf5_sbindir    %{_sbindir}
%define _kf5_notifydir  %{_kf5_sharedir}/knotifications5
%define _kf5_sysconfdir %{_sysconfdir}
%define _kf5_plugindir  %{_kf5_libdir}/qt5/plugins
%define _kf5_plasmadir  %{_kf5_sharedir}/plasma
%define _kf5_importdir  %{_kf5_libdir}/qt5/imports
%define _kf5_qmldir     %{_kf5_libdir}/qt5/qml
%define _kf5_cmakedir   %{_kf5_libdir}/cmake
%define _kf5_mkspecsdir %{_kf5_libdir}/qt5/mkspecs/modules
%define _kf5_appstreamdir    %{_kf5_sharedir}/metainfo
%define _kf5_dbusinterfacesdir %{_kf5_sharedir}/dbus-1/interfaces
%define _kf5_dbuspolicydir   %{_kf5_sharedir}/dbus-1/system.d
%define _kf5_configdir       %{_kf5_sysconfdir}/xdg
%define _kf5_iconsdir        %{_kf5_sharedir}/icons
%define _kf5_wallpapersdir   %{_kf5_sharedir}/wallpapers
%define _kf5_appsdir         %{_kf5_sharedir}
%define _kf5_configkcfgdir   %{_kf5_sharedir}/config.kcfg
%define _kf5_servicesdir     %{_kf5_sharedir}/kservices5
%define _kf5_servicetypesdir %{_kf5_sharedir}/kservicetypes5
%define _kf5_htmldir         %{_kf5_sharedir}/doc/HTML
%define _kf5_kxmlguidir      %{_kf5_sharedir}/kxmlgui5
%define _kf5_knsrcfilesdir   %{_kf5_sharedir}/knsrcfiles
%define _kf5_debugdir        %{_kf5_sharedir}/qlogging-categories5

%prep
%autosetup -T -c
cp %{SOURCE1} .

%build

%install
install -D -m644 %{SOURCE0} %{buildroot}%{_rpmconfigdir}/macros.d/macros.kf5
%if 0%{?suse_version} >= 1550
# On TW, foo-lang packages use automatic locale(foo:en) provides, but that
# does not match locale/kf5
install -D -m644 %{SOURCE2} %{buildroot}%{_rpmconfigdir}/fileattrs/localekf5.attr
install -D -m755 %{SOURCE3} %{buildroot}%{_rpmconfigdir}/fileattrs/localekf5.prov
%endif

mkdir -p %{buildroot}%{_kf5_datadir}
mkdir -p %{buildroot}%{_kf5_importdir}
mkdir -p %{buildroot}%{_kf5_includedir}
mkdir -p %{buildroot}%{_kf5_libexecdir}
mkdir -p %{buildroot}%{_kf5_notifydir}
mkdir -p %{buildroot}%{_kf5_plasmadir}
mkdir -p %{buildroot}%{_kf5_plugindir}
mkdir -p %{buildroot}%{_kf5_plugindir}/kf5
mkdir -p %{buildroot}%{_kf5_qmldir}
mkdir -p %{buildroot}%{_kf5_cmakedir}
mkdir -p %{buildroot}%{_kf5_mkspecsdir}
mkdir -p %{buildroot}%{_kf5_dbusinterfacesdir}
mkdir -p %{buildroot}%{_kf5_dbuspolicydir}
mkdir -p %{buildroot}%{_kf5_configdir}
mkdir -p %{buildroot}%{_kf5_wallpapersdir}
mkdir -p %{buildroot}%{_kf5_configkcfgdir}
mkdir -p %{buildroot}%{_kf5_servicesdir}
mkdir -p %{buildroot}%{_kf5_servicetypesdir}
mkdir -p %{buildroot}%{_kf5_htmldir}
mkdir -p %{buildroot}%{_kf5_kxmlguidir}
mkdir -p %{buildroot}%{_kf5_appstreamdir}
mkdir -p %{buildroot}%{_kf5_knsrcfilesdir}
mkdir -p %{buildroot}%{_kf5_debugdir}

for size in scalable 128x128 64x64 48x48 32x32 22x22 16x16; do
  for type in actions apps devices filesystems mimetypes places status; do
    mkdir -p %{buildroot}%{_kf5_sharedir}/icons/oxygen/$size/$type
  done
done
mkdir -p %{buildroot}%{_kf5_sharedir}/icons/oxygen/scalable/apps/small/{16x16,32x32}
mkdir -p %{buildroot}%{_kf5_sharedir}/icons/oxygen/scalable/status/small/{16x16,22x22,48x48}

# Own the htmldocs directories for all supported languages
pushd /usr/share/locale
for i in *; do
    mkdir %{buildroot}%{_kf5_htmldir}/$i
    # Work around that filesystem does not own all supported subdirs...
    mkdir -p %{buildroot}%{_mandir}/$i/man1
done
popd

%files
%license COPYING
%{_rpmconfigdir}/macros.d/macros.kf5
%if 0%{?suse_version} >= 1550
%{_rpmconfigdir}/fileattrs/localekf5.attr
%{_rpmconfigdir}/fileattrs/localekf5.prov
%endif
%dir %{_kf5_datadir}
%dir %{_kf5_includedir}
%dir %{_kf5_libexecdir}
%dir %{_mandir}/*
%dir %{_mandir}/*/man1
%dir %{_kf5_notifydir}
%dir %{_kf5_libdir}/qt5
%dir %{_kf5_plugindir}
%dir %{_kf5_plugindir}/kf5
%dir %{_kf5_plasmadir}
%dir %{_kf5_importdir}
%dir %{_kf5_qmldir}
%dir %{_kf5_cmakedir}
%dir %{_kf5_libdir}/qt5/mkspecs
%dir %{_kf5_mkspecsdir}
%dir %{_kf5_sharedir}/dbus-1
%dir %{_kf5_dbuspolicydir}
%dir %{_kf5_dbusinterfacesdir}
%dir %{_kf5_configdir}
%dir %{_kf5_iconsdir}/oxygen
%dir %{_kf5_iconsdir}/oxygen/*
%dir %{_kf5_iconsdir}/oxygen/*/*
%dir %{_kf5_wallpapersdir}
%dir %{_kf5_configkcfgdir}
%dir %{_kf5_servicesdir}
%dir %{_kf5_servicetypesdir}
%dir %{_kf5_sharedir}/doc/HTML
%dir %{_kf5_sharedir}/doc/HTML/en
%dir %{_kf5_kxmlguidir}
%dir %{_kf5_appstreamdir}
%dir %{_kf5_knsrcfilesdir}
%dir %{_kf5_debugdir}
%dir %{_kf5_htmldir}
%dir %{_kf5_htmldir}/*

%changelog
* Sun Sep  4 2022 Andreas Stieger <andreas.stieger@gmx.de>
- macros.kf5: convert obsolete egrep call to grep -E
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update the libexec path (boo#1174075)
- Make kf5-filesystem own %%{_kf5_plugindir}/kf5
* Fri Oct 16 2020 Christophe Giboudeaux <christophe@krop.fr>
- Make kf5-filesystem 'own' a couple more directories:
  * %%_kf5_configkcfgdir
  * %%_kf5_mkspecsdir
  * %%_kf5_wallpapersdir
- Use the same sorting for variable definition, folder creation
  and the %%files section
- Remove duplicate entries
- Don't try to create folders already owned by the filesystem package
- Stop creating crystalsvg and locolor subfolders in the
  icons directory
- Drop the python condition. The macros never worked
- Replace the python macros with stubs
- Require hicolor-icon-theme instead of creating empty directories
* Tue Mar 31 2020 Fabian Vogt <fvogt@suse.com>
- Use %%license
- Drop condition for Leap <= 42.1
- Add localekf5.attr and localekf5.prov (boo#1167317)
* Thu Jul 18 2019 Christophe Giboudeaux <christophe@krop.fr>
- Fix installation if kf5_makeinstall is used without parameter.
* Wed Jul 17 2019 Christophe Giboudeaux <christophe@krop.fr>
- Move the remaining logging categories files out of _kf5_configdir.
* Wed Jun 12 2019 Luca Beltrame <lbeltrame@kde.org>
- Move kf5_debugdir to _kf5_sharedir/qlogging-categories5 to
  reflect the new location in KF 5.59
* Wed Jun 12 2019 Wolfgang Bauer <wbauer@tmo.at>
- Add new macro _kf5_dbuspolicydir to handle the new dbus policy
  installation dir from KF 5.59
* Mon Mar 18 2019 Luca Beltrame <lbeltrame@kde.org>
- Add new macro (_kf5_knsrcfilesdir) to handle the new knsrc
  installation dir from KF 5.57
* Tue Dec 19 2017 lbeltrame@kde.org
- Add a new macro for debug category file installation
  (*.categories)
* Sun Dec 17 2017 fabian@ritter-vogt.de
- Move macros.kf5 to /usr/lib/rpm/macros.d/
* Tue Dec 12 2017 fvogt@suse.com
- Properly escape some %%
- Remove en docs from an existing .lang file in %%kf5_find_lang
  to fix conflicts with rpm 4.14's find_lang.sh
* Fri Apr 14 2017 fabian@ritter-vogt.de
- Add %%kf5_find_htmldocs macro to generate a filelist of all
  translated htmldocs
- Own all directories for supported htmldoc translations
- Same for man
* Wed Apr  5 2017 fabian@ritter-vogt.de
- Add %%_kf5_py2kf5dir and %%_kf5_py3kf5dir, create __init__.py within
- Do not own %%_kf5_sharedir (/usr/share) as it's part of filesystem
- Add %%_kf5_pysipdir, but do not own it. Used for devel packages of
  python bindings
- Add %%kf5_python_bindings_package to auto-generate Python binding
  subpackage descriptions (for both Python 2 and 3).
* Tue Mar 21 2017 fabian@ritter-vogt.de
- Extend %%kf5_find_lang to support LC_SCRIPTS files as well
* Wed Aug 24 2016 fabian@ritter-vogt.de
- Own %%_kf5_appstreamdir
* Wed Aug 17 2016 fabian@ritter-vogt.de
- Use metainfo for %%_kf5_appstreamdir on Leap >= 42.2
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Use appdata dir for %%_kf5_appstreamdir on older oS releases
* Wed Apr 20 2016 hrvoje.senjan@gmail.com
- Define %%_kf5_appstreamdir
* Sat Apr  9 2016 hrvoje.senjan@gmail.com
- Explicitly disable KDE_INSTALL_USE_QT_SYS_PATHS: we don't trust
  upstream enough to use absolute paths everywhere
* Mon Sep 21 2015 wbauer@tmo.at
- Add a new %%kf5_find_lang macro. Purpose and usage is similar to
  the standard %%find_lang macro (on which this is loosely based),
  but it only looks for translations files in /usr/share/locale/kf5
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Fix the create_subdir_filelist macro.
* Thu Jul  2 2015 tchvatal@suse.com
- Respect CFLAGS and CXXFLAGS if present in environment like
  regular %%cmake macro
* Wed Jun 10 2015 hrvoje.senjan@gmail.com
- Change versionining from KF5-version-based to date-based
- Drop and %%_kf5_version %%_plasma5_branding_version macros.
  _kf5_version is unused since KF5 5.5.0, and for plasma we can
  utilize individual packages version
- Add a warning that these macros are only guaranteed to be suitable
  for projects/packages which use KDEInstallDirs from extra-cmake-modules,
  and can, to some extent work with cmake's GNUInstallDirs.
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Use new KDE_ variables in cmake_kf5 macro
- Bump to 5.6.0
* Sat Jan  3 2015 tittiatcoke@gmail.com
- Add KF5 xmlguidir to macros
* Thu Sep 25 2014 hrvoje.senjan@gmail.com
- Add KF5 localedir to macros
* Mon Sep  8 2014 hrvoje.senjan@gmail.com
- Bump to 5.2.0
* Sat Aug  2 2014 hrvoje.senjan@gmail.com
- Bump to 5.1.0
- Stop passing relative vars as absolute (that works with regards
  to installing files, but breaks when used as #define)
* Tue Jul  1 2014 hrvoje.senjan@gmail.com
- Bump to 5.0.0
- Make buildtype None, and pass -DNEDEBUG to cmake flags (this avoids
  passing different compiler optimizations, e.g. -02 vs -03)
* Sun Jun  1 2014 hrvoje.senjan@gmail.com
- Bump to 4.100.0
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Bump to 4.99.0
- Adjust macros per latest defaults in extra-cmake-modules
* Fri Apr 18 2014 hrvoje.senjan@gmail.com
- Add as-needed, no-undefined and -Bsymbolic-functions link flags
  to cmake_kf5 macro
* Sat Mar 29 2014 hrvoje.senjan@gmail.com
- Bump to 4.98.0
* Sat Mar  1 2014 hrvoje.senjan@gmail.com
- Bump to 4.97.0
* Sat Feb  8 2014 hrvoje.senjan@gmail.com
- Init kf5-filesystem package
